@@ -171,23 +171,14 @@ class FieldDiffContainer(BucketModel):
     @staticmethod
     def _diff(a: dict[str, Field], b: dict[str, Field]) -> list[FieldDiff]:
         from ..declarative import (
-            EntitySet,
-            EntitySetDiff,
-            ValueObjectSet,
-            ValueObjectSetDiff,
+            IncrementalSet,
         )
 
         differences = list()
         for a_name, a_field in a.items():
             if a_name not in b or a_field != b[a_name]:
-                if isinstance(a_field.value, EntitySet):
-                    diffs = EntitySetDiff.from_difference(a_field.value, b[a_name].value).diffs
-                    for diff in diffs:
-                        differences.append(
-                            IncrementalFieldDiff(a_name, get_args(a_field.type)[0], diff.entity, diff.action)
-                        )
-                elif isinstance(a_field.value, ValueObjectSet):
-                    diffs = ValueObjectSetDiff.from_difference(a_field.value, b[a_name].value).diffs
+                if isinstance(a_field.value, IncrementalSet):
+                    diffs = a_field.value.diff(b[a_name].value).diffs
                     for diff in diffs:
                         differences.append(
                             IncrementalFieldDiff(a_name, get_args(a_field.type)[0], diff.entity, diff.action)
